@@ -211,16 +211,12 @@ Provide a place lookup gazeteer based on files from geonames.org
             self.geo_build.geodb.s.lookup_geoid(georow_list=place.georow_list, geoid=place.geoid, place=place, admin=True)
 
         if len(place.georow_list) > 0:
-            # Copy geo row to Place
-            #self.geo_build.geodb.copy_georow_to_place(row=place.georow_list[0], place=place, fast=True)
-            #flags = self.filter_results(place)
-            self.process_results(place=place, flags=flags)
-            # place.original_entry = place.get_long_name(None)
-            #self.logger.debug(f'found geoid {place.georow_list[0]}')
             place.result_type = GeoUtil.Result.STRONG_MATCH
+            self.process_results(place=place, flags=flags)
+            #self.logger.debug(f'found geoid {place.georow_list[0]}')
         else:
             place.result_type = GeoUtil.Result.NO_MATCH
-            self.logger.debug(f'NOT FOUND geoid {geoid}')
+            #self.logger.debug(f'NOT FOUND geoid {geoid}')
 
     def _find_type_as_city(self, place: Loc, typ):
         """
